#pragma once

#ifndef TAG_UTILS_
#define TAG_UTILS_

#include <stdio.h>
#include<stdint.h>

//NRF libs
#include "nrf_delay.h" //ToDo Avoid the delay

#define DEBUG_LED_BLINK_DELAY_MS 30

#define LONG_PRESS_TIME_MS 2000

// Define the tick rate in milliseconds
#define TICK_RATE_MS 100

#define RESET_BUTTON_DETECTION_DELAY APP_TIMER_TICKS(5)

typedef enum TAG_LED_MODE {
  TAG_RECEIVING_E2_DATA,        // Indicating the E2 beacon is being detected and is being saved
  TAG_GATT_ADV_MODE,            // Indicating hub beacon was detected and the TAG is not advertising GATT Adv packets
  TAG_GATT_CLIENT_CONNECTED,    // Indicating the HUB is connected
  TAG_TRANSMITTING_DATA,        // Indicating the TAG is tranmitting data to HUB
  TAG_TO_HUB_TRANSFER_COMPLETE, // Indicating the data was saved to the hub
  TAG_ALL_LED_OFF
} tag_led_modes_e;

/**
 * Function to intialize the TAG leds
 */
void tag_init_led(void);

#ifdef TAG_DEBUG_MODE
/**
 * Function to handle the led switching
 */
void switch_led_debug_mode(tag_led_modes_e mode);
#endif

/**
* Initialise the tag buttons
*/
void tag_btns_init();

/**
* Function to intialize the Boot Timer
*/
void boot_timer_init();


void tag_init_battery_pins(void);

/**
* Function to check and update the Battery indication
*/

 void check_and_update_battery_state();

uint64_t millis(void);

/**
* Function to get the battery level
*/
uint16_t get_battery_level();

#endif // TAG_UTILS_